@@ -12,7 +12,7 @@ use Compiled::Params::OO qw/cpo/;
 use XML::RSS::LibXML;
 
 use 5.006;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 our $validate;
 BEGIN {
@@ -220,7 +220,7 @@ Feed::Data is a frontend for building dynamic data feeds.
 
 Populates the feed Attribute, this is an Array of Feed::Data::Object 's
 
-You can currently build Feeds by parsing xml (RSS, ATOM) and HTML via Meta Tags (twitter, opengraph);
+You can currently build Feeds by parsing xml (RSS, ATOM), JSON, HTML via Meta Tags (twitter, opengraph) and plain text using key values seperated by a colon;
 
 =cut
 
@@ -233,7 +233,7 @@ You can currently build Feeds by parsing xml (RSS, ATOM) and HTML via Meta Tags
 
 =item File
 
-	$feed->parse( 'path/to/feed.xml' );
+	$feed->parse( 'path/to/feed.json' );
 
 =item Raw 
 
